from NR_BS_3GPP_Rx_Px_tests.General.Base import BSTestBase
from NR_BS_3GPP_Rx_Px_tests.General.Utilities import RsException
from RsSmw.Internal.InstrumentErrors import RsInstrException
from RsSmw import enums


class TC841(BSTestBase):
    def __init__(self, resource_string: str):
        super().__init__(resource_string)
        self.driver.source.bb.nr5G.tcw.set_spec(test_spec=enums.TestSpec.TS38141_1)
        self.driver.source.bb.nr5G.tcw.set_tc(test_case=enums.TestCase.TS381411_TC841)
        self.spec_release: enums.Release = self.driver.source.bb.nr5G.tcw.get_release()
        """enums.Release: Select specification release"""
        self.driver.source.bb.nr5G.tcw.set_release(release=self.spec_release)

        self.bs_class: enums.BsClass = self.driver.source.bb.nr5G.tcw.get_bs_class()
        """enums.BsClass: Select base station class"""

        self.trigger_config: enums.TrigConf = self.driver.source.bb.nr5G.tcw.get_trigger_config()
        """enums.TrigConf: Select trigger configuration"""
        self.marker_config: enums.MarkConf = self.driver.source.bb.nr5G.tcw.get_marker_config()
        """enums.MarkConf: Select marker configuration"""

        self.tx_antennas: enums.TxAntenna = self.driver.source.bb.nr5G.tcw.ant.get_tx_antennas()
        """enums.TxAntenna: Select the number of transmit antennas"""
        self.rx_antennas: enums.RxaNt = self.driver.source.bb.nr5G.tcw.ant.get_rx_antennas()
        """enums.RxaNt: Select the number of receive antennas"""

        self.mode = self.driver.source.bb.nr5G.tcw.ws.get_mode()
        """enums.Mode: Select mode: Detection rate mode or False detection rate mode"""
        self.frequency: float = self.driver.source.bb.nr5G.tcw.ws.get_rf_frequency()
        """float: Set frequency in Hz"""
        self.channel_bw: enums.Nr5Gcbw = self.driver.source.bb.nr5G.tcw.ws.get_cbw()
        """enums.Nr5Gcbw: Select channel bandwidth"""
        self.scs: enums.Numerology = self.driver.source.bb.nr5G.tcw.ws.get_sc_spacing()
        """enums.Numerology: Select subcarrier spacing"""
        self.preamble_format: enums.TcwpRachFormat = self.driver.source.bb.nr5G.tcw.ws.prach.get_format_py()
        """enums.TcwpRachFormat: Select PRACH preamble format"""
        self.scs_prach: enums.TcwfEedbackMode = self.driver.source.bb.nr5G.tcw.ws.prach.get_sc_spacing()
        """enums.TcwfEedbackMode: Set sub carrier spacing (PRACH)"""
        self.cell_id: int = self.driver.source.bb.nr5G.tcw.ws.get_cellid()
        """int: Set cell id"""
        self.ue_id: int = self.driver.source.bb.nr5G.tcw.ws.get_ueid()
        """int: Set user equipment id"""
        self.frequency_offset: enums.FreqOffset = self.driver.source.bb.nr5G.tcw.ws.get_fr_offset()
        """Select the frequency offset used for PRACH: 0, 400 or 4000 Hz"""
        self.prop_cond: enums.PropagCond = self.driver.source.bb.nr5G.tcw.ws.get_pro_condition()
        """enums.PropagCond: Select the propagation conditions"""
        self.dmrs_pos: int = self.driver.source.bb.nr5G.tcw.ws.get_tapos()
        """int: Set the DMRS type a position"""

    def apply_configuration(self):
        """
        This function applies the configuration and sends the remote control commands to the connected device.
        :return:
        """
        try:
            self.driver.source.bb.nr5G.tcw.set_bs_class(self.bs_class)
            self.driver.source.bb.nr5G.tcw.set_trigger_config(trig_config=self.trigger_config)
            self.driver.source.bb.nr5G.tcw.set_marker_config(marker_config=self.marker_config)
            self.driver.source.bb.nr5G.tcw.ant.set_tx_antennas(tx_antennas=self.tx_antennas)
            self.driver.source.bb.nr5G.tcw.ant.set_rx_antennas(rx_antennas=self.rx_antennas)

            self.driver.source.bb.nr5G.tcw.ws.set_mode(mode=self.mode)
            self.driver.source.bb.nr5G.tcw.ws.set_rf_frequency(ws_rf_freq=self.frequency)
            self.driver.source.bb.nr5G.tcw.ws.set_cbw(ws_ch_bw=self.channel_bw)
            self.driver.source.bb.nr5G.tcw.ws.set_sc_spacing(ws_sub_car_spacing=self.scs)
            self.driver.source.bb.nr5G.tcw.ws.prach.set_format_py(prach_format=self.preamble_format)
            self.driver.source.bb.nr5G.tcw.ws.prach.set_sc_spacing(prach_scs=self.scs_prach)
            self.driver.source.bb.nr5G.tcw.ws.set_cellid(ws_cell_id=self.cell_id)
            self.driver.source.bb.nr5G.tcw.ws.set_ueid(ws_ueid=self.ue_id)
            self.driver.source.bb.nr5G.tcw.ws.set_fr_offset(freq_offset=self.frequency_offset)
            self.driver.source.bb.nr5G.tcw.ws.set_pro_condition(propag_cond=self.prop_cond)
            self.driver.source.bb.nr5G.tcw.ws.set_tapos(ws_typea_pos=self.dmrs_pos)

            self.driver.source.bb.nr5G.tcw.apply.set()

        except RsInstrException as e:
            raise RsException(e.args[0])

    def switch_rf_on(self):
        """
        This function switches the RF output(s) on
        """
        self.driver.output.all.set_state(state=True)

    def switch_rf_off(self):
        """
        This function switches the RF output(s) off
        """
        self.driver.output.all.set_state(state=False)
