"""
5G NR base station conformance tests according to 3GPP TS38141-1 (autogenerated driver);
:version: 1.00
:copyright: 2020 by Rohde & Schwarz GMBH & Co. KG
:license: MIT
:author: Christian Wicke, Fabian Bette
Numbering refers to numbering in 3GPP TS 38.141-1:

--- TS38.141-1 Test cases:
TC 7.2: Reference sensitivity level
TC 7.3: Dynamic range
TC 7.4.1: Adjacent channel selectivity (ACS)
TC 7.4.2a: In-band blocking: General
TC 7.4.2b: In-band blocking: Narrow-band blocking
TC 7.5: Out-of-band blocking
TC 7.6: Receiver spurious emissions (not supported: Spectrum analyzer is required)
TC 7.7: Receiver intermodulation (not supported: Additional CW generator is required)
TC 7.8: In-channel selectivity

TC 8.2.1: Performance requirement for PUSCH with transform precoding disabled
TC 8.2.2: Performance requirement for PUSCH with transform precoding enabled
TC 8.2.3: Performance requirements for UCI multiplexed on PUSCH
TC 8.3.1: Performance requirements for PUCCH format 0
TC 8.3.2: Performance requirements for PUCCH format 1
TC 8.3.3: Performance requirements for PUCCH format 2
TC 8.3.4: Performance requirements for PUCCH format 3
TC 8.3.5: Performance requirements for PUCCH format 4
TC 8.3.6.1: Performance requirements for multi-slot PUCCH format 1
TC 8.4.1: PRACH false alarm probability and missed detection
"""

__version__ = '1.00'

from NR_BS_3GPP_Rx_Px_tests.General.Utilities import RsException
from RsSmw import enums

from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter7_Rx_TCs.TC_7_2 import TC72
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter7_Rx_TCs.TC_7_3 import TC73
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter7_Rx_TCs.TC_7_4_1 import TC741
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter7_Rx_TCs.TC_7_4_2A import TC742A
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter7_Rx_TCs.TC_7_4_2B import TC742B
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter7_Rx_TCs.TC_7_5 import TC75
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter7_Rx_TCs.TC_7_8 import TC78

from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_2_1 import TC821
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_2_2 import TC822
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_2_3 import TC823
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_1 import TC831
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_2_1 import TC8321
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_2_2 import TC8322
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_3_1 import TC8331
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_3_2 import TC8332
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_4 import TC834
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_5 import TC835
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_6_1A import TC8361A
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_3_6_1B import TC8361B
from NR_BS_3GPP_Rx_Px_tests.TS38141_1.Chapter8_Px_TCs.TC_8_4_1 import TC841
