from NR_BS_3GPP_Rx_Px_tests.General.Base import BSTestBase
from NR_BS_3GPP_Rx_Px_tests.General.Utilities import RsException
from RsSmw.Internal.InstrumentErrors import RsInstrException
from RsSmw import enums


class TC822(BSTestBase):
    def __init__(self, resource_string: str):
        super().__init__(resource_string)
        self.driver.source.bb.nr5G.tcw.set_spec(test_spec=enums.TestSpec.TS38141_2)
        self.driver.source.bb.nr5G.tcw.set_tc(test_case=enums.TestCase.TS381412_TC822)
        self.spec_release: enums.Release = self.driver.source.bb.nr5G.tcw.get_release()
        """enums.Release: Select specification release"""
        self.driver.source.bb.nr5G.tcw.set_release(release=self.spec_release)

        self.bs_class: enums.BsClass = self.driver.source.bb.nr5G.tcw.get_bs_class()
        """enums.BsClass: Select base station class"""

        self.bs_type: enums.BsType = self.driver.source.bb.nr5G.tcw.get_bs_type()
        """enums.BsType: Select the base station type for the OTA settings"""
        self.dcl_direction: enums.DeclaredDir = self.driver.source.bb.nr5G.tcw.get_dcl_direction()
        """enums.DeclaredDir: Select the referece for the OSDD"""
        self.meis: float = self.driver.source.bb.nr5G.tcw.get_meis()
        """float: Set the lowest equivalent isotropic sensitivity value for the OSDD [dBm]"""
        self.eis_50m: float = self.driver.source.bb.nr5G.tcw.get_e_50()
        """float: Set the EISREFSENS 50m level value [dBm]"""
        self.bew_theta: float = self.driver.source.bb.nr5G.tcw.get_bewthet()
        """float: Set the angle of the beamwidth for the OTA REFSENS RoAoA (Theta-axis) [deg]"""
        self.bew_phi: float = self.driver.source.bb.nr5G.tcw.get_bewphi()
        """float: Set the angle of the beamwidth for the OTA REFSENS RoAoA (Phi-axis) [deg]"""

        self.trigger_config: enums.TrigConf = self.driver.source.bb.nr5G.tcw.get_trigger_config()
        """enums.TrigConf: Select trigger configuration"""
        self.marker_config: enums.MarkConf = self.driver.source.bb.nr5G.tcw.get_marker_config()
        """enums.MarkConf: Select marker configuration"""

        self.tx_antennas: enums.TxAntenna = self.driver.source.bb.nr5G.tcw.ant.get_tx_antennas()
        """enums.TxAntenna: Select the number of transmit antennas"""
        self.rx_antennas: enums.RxaNt = self.driver.source.bb.nr5G.tcw.ant.get_rx_antennas()
        """enums.RxaNt: Select the number of receive antennas"""

        self.frequency: float = self.driver.source.bb.nr5G.tcw.ws.get_rf_frequency()
        """float: Set frequency in Hz"""
        self.duplex: enums.EutraDuplexMode = self.driver.source.bb.nr5G.tcw.ws.get_duplex()
        """enums.EutraDuplexMode: Select duplex mode: Frequency division duplex or time division duplex"""
        self.channel_bw: enums.Nr5Gcbw = self.driver.source.bb.nr5G.tcw.ws.get_cbw()
        """enums.Nr5Gcbw: Select channel bandwidth"""
        self.scs: enums.Numerology = self.driver.source.bb.nr5G.tcw.ws.get_sc_spacing()
        """enums.Numerology: Select subcarrier spacing"""
        self.cell_id: int = self.driver.source.bb.nr5G.tcw.ws.get_cellid()
        """int: Set cell id"""
        self.ue_id: int = self.driver.source.bb.nr5G.tcw.ws.get_ueid()
        """int: Set user equipment id"""
        self.prop_cond: enums.PropagCond = self.driver.source.bb.nr5G.tcw.ws.get_pro_condition()
        """enums.PropagCond: Select the propagation conditions"""
        self.mapping_type: enums.MappingType = self.driver.source.bb.nr5G.tcw.ws.get_map_type()
        """enums.MappingType: Select mapping type"""
        self.dmrs_pos: int = self.driver.source.bb.nr5G.tcw.ws.get_tapos()
        """int: Set the DMRS type a position"""
        self.rb_offset: int = self.driver.source.bb.nr5G.tcw.ws.get_rb_offset()
        """int: Set the shift of the allocated wanted signal in number of resource blocks"""

        self.feedback_mode: enums.TcwfEedbackMode = self.driver.source.bb.nr5G.tcw.rtf.get_mode()
        """enums.TcwfEedbackMode: Select the realtime feedback mode"""
        self.serial_rate: enums.FeedbackRateAll = self.driver.source.bb.nr5G.tcw.rtf.get_ser_rate()
        """enums.FeedbackRateAll: Select serial rate"""
        self.additional_user_delay: float = self.driver.source.bb.nr5G.tcw.rtf.get_aus_delay()
        """float: Set additional user delay (in number of slots)"""
        self.connector: enums.FeedbackConnector = self.driver.source.bb.nr5G.tcw.rtf.get_connector()
        """enums.FeedbackConnector: Select feedback connector"""
        self.baseband_selector: int = self.driver.source.bb.nr5G.tcw.rtf.get_bb_selector()
        """int: Set the baseband selector index"""

    def apply_configuration(self):
        """
        This function applies the configuration and sends the remote control commands to the connected device.
        :return:
        """
        try:

            self.driver.source.bb.nr5G.tcw.set_bs_class(self.bs_class)

            self.driver.source.bb.nr5G.tcw.set_bs_type(bs_type=self.bs_type)
            self.driver.source.bb.nr5G.tcw.set_dcl_direction(declared_dir=self.dcl_direction)
            self.driver.source.bb.nr5G.tcw.set_meis(minimum_eis=self.meis)
            self.driver.source.bb.nr5G.tcw.set_e_50(eis_50_m=self.eis_50m)
            self.driver.source.bb.nr5G.tcw.set_bewthet(be_wthet_ref_sens=self.bew_theta)
            self.driver.source.bb.nr5G.tcw.set_bewphi(be_wphi_ref_sens=self.bew_phi)

            self.driver.source.bb.nr5G.tcw.set_trigger_config(trig_config=self.trigger_config)
            self.driver.source.bb.nr5G.tcw.set_marker_config(marker_config=self.marker_config)

            self.driver.source.bb.nr5G.tcw.ant.set_tx_antennas(tx_antennas=self.tx_antennas)
            self.driver.source.bb.nr5G.tcw.ant.set_rx_antennas(rx_antennas=self.rx_antennas)

            self.driver.source.bb.nr5G.tcw.ws.set_rf_frequency(ws_rf_freq=self.frequency)
            self.driver.source.bb.nr5G.tcw.ws.set_duplex(duplexing=self.duplex)
            self.driver.source.bb.nr5G.tcw.ws.set_cbw(ws_ch_bw=self.channel_bw)
            self.driver.source.bb.nr5G.tcw.ws.set_sc_spacing(ws_sub_car_spacing=self.scs)
            self.driver.source.bb.nr5G.tcw.ws.set_cellid(ws_cell_id=self.cell_id)
            self.driver.source.bb.nr5G.tcw.ws.set_ueid(ws_ueid=self.ue_id)
            self.driver.source.bb.nr5G.tcw.ws.set_pro_condition(propag_cond=self.prop_cond)
            self.driver.source.bb.nr5G.tcw.ws.set_map_type(map_type=self.mapping_type)
            self.driver.source.bb.nr5G.tcw.ws.set_tapos(ws_typea_pos=self.dmrs_pos)
            self.driver.source.bb.nr5G.tcw.ws.set_rb_offset(ws_rb_offset=self.rb_offset)

            self.driver.source.bb.nr5G.tcw.rtf.set_mode(rtf_mode=self.feedback_mode)
            self.driver.source.bb.nr5G.tcw.rtf.set_ser_rate(serial_rate=self.serial_rate)
            self.driver.source.bb.nr5G.tcw.rtf.set_aus_delay(add_user_delay=self.additional_user_delay)
            self.driver.source.bb.nr5G.tcw.rtf.set_connector(connector=self.connector)
            self.driver.source.bb.nr5G.tcw.rtf.set_bb_selector(bb_selector=self.baseband_selector)

            self.driver.source.bb.nr5G.tcw.apply.set()

        except RsInstrException as e:
            raise RsException(e.args[0])

    def switch_rf_on(self):
        """
        This function switches the RF output(s) on
        """
        self.driver.output.all.set_state(state=True)

    def switch_rf_off(self):
        """
        This function switches the RF output(s) off
        """
        self.driver.output.all.set_state(state=False)
