from NR_BS_3GPP_Rx_Px_tests.General.Base import BSTestBase
from NR_BS_3GPP_Rx_Px_tests.General.Utilities import RsException
from RsSmw.Internal.InstrumentErrors import RsInstrException
from RsSmw import enums


class TC831(BSTestBase):
    def __init__(self, resource_string: str, ):
        super().__init__(resource_string)
        self.driver.source.bb.nr5G.tcw.set_spec(test_spec=enums.TestSpec.TS38141_2)
        self.driver.source.bb.nr5G.tcw.set_tc(test_case=enums.TestCase.TS381412_TC831)
        self.spec_release: enums.Release = self.driver.source.bb.nr5G.tcw.get_release()
        """enums.Release: Select specification release"""
        self.driver.source.bb.nr5G.tcw.set_release(release=self.spec_release)

        self.bs_class: enums.BsClass = self.driver.source.bb.nr5G.tcw.get_bs_class()
        """enums.BsClass: Select base station class"""

        self.bs_type: enums.BsType = self.driver.source.bb.nr5G.tcw.get_bs_type()
        """enums.BsType: Select the base station type for the OTA settings"""
        self.dcl_direction: enums.DeclaredDir = self.driver.source.bb.nr5G.tcw.get_dcl_direction()
        """enums.DeclaredDir: Select the referece for the OSDD"""
        self.meis: float = self.driver.source.bb.nr5G.tcw.get_meis()
        """float: Set the lowest equivalent isotropic sensitivity value for the OSDD [dBm]"""
        self.eis_50m: float = self.driver.source.bb.nr5G.tcw.get_e_50()
        """float: Set the EISREFSENS 50m level value [dBm]"""
        self.bew_theta: float = self.driver.source.bb.nr5G.tcw.get_bewthet()
        """float: Set the angle of the beamwidth for the OTA REFSENS RoAoA (Theta-axis) [deg]"""
        self.bew_phi: float = self.driver.source.bb.nr5G.tcw.get_bewphi()
        """float: Set the angle of the beamwidth for the OTA REFSENS RoAoA (Phi-axis) [deg]"""

        self.trigger_config: enums.TrigConf = self.driver.source.bb.nr5G.tcw.get_trigger_config()
        """enums.TrigConf: Select trigger configuration"""
        self.marker_config: enums.MarkConf = self.driver.source.bb.nr5G.tcw.get_marker_config()
        """enums.MarkConf: Select marker configuration"""

        self.tx_antennas: enums.TxAntenna = self.driver.source.bb.nr5G.tcw.ant.get_tx_antennas()
        """enums.TxAntenna: Select the number of transmit antennas"""
        self.rx_antennas: enums.RxaNt = self.driver.source.bb.nr5G.tcw.ant.get_rx_antennas()
        """enums.RxaNt: Select the number of receive antennas"""

        self.mode = self.driver.source.bb.nr5G.tcw.ws.get_mode()
        """enums.Mode: Select mode: Detection rate mode or False detection rate mode"""
        self.frequency: float = self.driver.source.bb.nr5G.tcw.ws.get_rf_frequency()
        """float: Set frequency in Hz"""
        self.channel_bw: enums.Nr5Gcbw = self.driver.source.bb.nr5G.tcw.ws.get_cbw()
        """enums.Nr5Gcbw: Select channel bandwidth"""
        self.scs: enums.Numerology = self.driver.source.bb.nr5G.tcw.ws.get_sc_spacing()
        """enums.Numerology: Select subcarrier spacing"""
        self.number_ofdm = self.driver.source.bb.nr5G.tcw.ws.get_sym_number()
        """Set the number of used OFDM symbols"""
        self.cell_id: int = self.driver.source.bb.nr5G.tcw.ws.get_cellid()
        """int: Set cell id"""
        self.ue_id: int = self.driver.source.bb.nr5G.tcw.ws.get_ueid()
        """int: Set user equipment id"""
        self.prop_cond: enums.PropagCond = self.driver.source.bb.nr5G.tcw.ws.get_pro_condition()
        """enums.PropagCond: Select the propagation conditions"""
        self.dmrs_pos: int = self.driver.source.bb.nr5G.tcw.ws.get_tapos()
        """int: Set the DMRS type a position"""

    def apply_configuration(self):
        """
        This function applies the configuration and sends the remote control commands to the connected device.
        :return:
        """
        try:
            self.driver.source.bb.nr5G.tcw.set_bs_class(self.bs_class)

            self.driver.source.bb.nr5G.tcw.set_bs_type(bs_type=self.bs_type)
            self.driver.source.bb.nr5G.tcw.set_dcl_direction(declared_dir=self.dcl_direction)
            self.driver.source.bb.nr5G.tcw.set_meis(minimum_eis=self.meis)
            self.driver.source.bb.nr5G.tcw.set_e_50(eis_50_m=self.eis_50m)
            self.driver.source.bb.nr5G.tcw.set_bewthet(be_wthet_ref_sens=self.bew_theta)
            self.driver.source.bb.nr5G.tcw.set_bewphi(be_wphi_ref_sens=self.bew_phi)

            self.driver.source.bb.nr5G.tcw.set_trigger_config(trig_config=self.trigger_config)
            self.driver.source.bb.nr5G.tcw.set_marker_config(marker_config=self.marker_config)
            self.driver.source.bb.nr5G.tcw.ant.set_tx_antennas(tx_antennas=self.tx_antennas)
            self.driver.source.bb.nr5G.tcw.ant.set_rx_antennas(rx_antennas=self.rx_antennas)

            self.driver.source.bb.nr5G.tcw.ws.set_mode(mode=self.mode)
            self.driver.source.bb.nr5G.tcw.ws.set_rf_frequency(ws_rf_freq=self.frequency)
            self.driver.source.bb.nr5G.tcw.ws.set_cbw(ws_ch_bw=self.channel_bw)
            self.driver.source.bb.nr5G.tcw.ws.set_sc_spacing(ws_sub_car_spacing=self.scs)
            self.driver.source.bb.nr5G.tcw.ws.set_sym_number(symbol_number=self.number_ofdm)
            self.driver.source.bb.nr5G.tcw.ws.set_cellid(ws_cell_id=self.cell_id)
            self.driver.source.bb.nr5G.tcw.ws.set_ueid(ws_ueid=self.ue_id)
            self.driver.source.bb.nr5G.tcw.ws.set_pro_condition(propag_cond=self.prop_cond)
            self.driver.source.bb.nr5G.tcw.ws.set_tapos(ws_typea_pos=self.dmrs_pos)

            self.driver.source.bb.nr5G.tcw.apply.set()

        except RsInstrException as e:
            raise RsException(e.args[0])

    def switch_rf_on(self):
        """
        This function switches the RF output(s) on
        """
        self.driver.output.all.set_state(state=True)

    def switch_rf_off(self):
        """
        This function switches the RF output(s) off
        """
        self.driver.output.all.set_state(state=False)
