"""
5G NR base station conformance tests according to 3GPP TS38141-2 (autogenerated driver);
:version: 1.00
:copyright: 2020 by Rohde & Schwarz GMBH & Co. KG
:license: MIT
:author: Christian Wicke, Fabian Bette
Numbering refers to numbering in 3GPP TS 38.141-2:

TC 7.2: OTA sensitivity
TC 7.3: OTA reference sensitivity level
TC 7.4: OTA dynamic range
TC 7.5.1: OTA adjacent channel selectivity (ACS)
TC 7.5.2A: OTA in-band General Blocking
TC 7.5.2B: OTA in-band narrowband Blocking
TC 7.6: OTA out-of-band blocking (not supported: Additional CW generator is required)
TC 7.7: OTA receiver spurious emissions (not supported: Spectrum analyzer is required)
TC 7.8: OTA receiver intermodulation (not supported: Additional CW generator is required)
TC 7.9: OTA in-channel sensitivity

TC 8.2.1: OTA PUSCH transform precoding disabled
TC 8.2.2: OTA PUSCH transform precoding enabled
TC 8.2.3: OTA UCI multiplexed on PUSCH
TC 8.3.1: OTA performance requirements for PUCCH format 0
TC 8.3.2.1: OTA NACK to ACK detection for PUCCH format 1
TC 8.3.2.2: OTA ACK missed detection for PUCCH format 1
TC 8.3.3.1: OTA ACK missed detection for PUCCH format 2
TC 8.3.3.2: OTA UCI BLER for PUCCH format 2
TC 8.3.4: OTA performance requirements for PUCCH format 3
TC 8.3.5: OTA performance requirements for PUCCH format 4
TC 8.3.6.1A: OTA NACK to ACK detection for multi-slot PUCCH format 1
TC 8.3.6.1B: OTA ACK missed detection for multi-slot PUCCH format 1
TC 8.4.1: OTA PRACH false alarm probability and missed detection

"""
__version__ = '1.00'

from NR_BS_3GPP_Rx_Px_tests.General.Utilities import RsException
from RsSmw import enums

from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter7_Rx_TCs.TC_7_2 import TC72
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter7_Rx_TCs.TC_7_3 import TC73
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter7_Rx_TCs.TC_7_4 import TC74
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter7_Rx_TCs.TC_7_5_1 import TC751
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter7_Rx_TCs.TC_7_5_2A import TC752A
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter7_Rx_TCs.TC_7_5_2B import TC752B
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter7_Rx_TCs.TC_7_9 import TC79

from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_2_1 import TC821
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_2_2 import TC822
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_2_3 import TC823
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_1 import TC831
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_2_1 import TC8321
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_2_2 import TC8322
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_3_1 import TC8331
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_3_2 import TC8332
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_4 import TC834
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_5 import TC835
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_6_1A import TC8361A
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_3_6_1B import TC8361B
from NR_BS_3GPP_Rx_Px_tests.TS38141_2.Chapter8_Px_TCs.TC_8_4_1 import TC841